==> whylabs-client-0.6.4.tar.gz: whylabs-client-0.6.4/whylabs_client/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.api_key_api import ApiKeyApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from whylabs_client.api.api_key_api import ApiKeyApi
from whylabs_client.api.assets_api import AssetsApi
from whylabs_client.api.container_diagnostics_api import ContainerDiagnosticsApi
from whylabs_client.api.data_api import DataApi
from whylabs_client.api.dataset_profile_api import DatasetProfileApi
from whylabs_client.api.dataset_metadata_api import DatasetMetadataApi
from whylabs_client.api.debug_events_api import DebugEventsApi
from whylabs_client.api.feature_weights_api import FeatureWeightsApi
from whylabs_client.api.log_api import LogApi
from whylabs_client.api.membership_api import MembershipApi
from whylabs_client.api.models_api import ModelsApi
from whylabs_client.api.monitor_api import MonitorApi
from whylabs_client.api.monitor_diagnostics_api import MonitorDiagnosticsApi
from whylabs_client.api.notification_settings_api import NotificationSettingsApi
from whylabs_client.api.policy_api import PolicyApi
from whylabs_client.api.schema_api import SchemaApi
from whylabs_client.api.security_api import SecurityApi
from whylabs_client.api.sessions_api import SessionsApi
from whylabs_client.api.traces_api import TracesApi
from whylabs_client.api.transactions_api import TransactionsApi

==> whylabs-client-0.6.5.tar.gz: whylabs-client-0.6.5/whylabs_client/apis/__init__.py <==

# flake8: noqa

# Import all APIs into this package.
# If you have many APIs here with many many models used in each API this may
# raise a `RecursionError`.
# In order to avoid this, import only the API that you directly need like:
#
#   from .api.api_key_api import ApiKeyApi
#
# or import this package, but before doing it, use:
#
#   import sys
#   sys.setrecursionlimit(n)

# Import APIs into API package:
from whylabs_client.api.api_key_api import ApiKeyApi
from whylabs_client.api.assets_api import AssetsApi
from whylabs_client.api.data_api import DataApi
from whylabs_client.api.dataset_profile_api import DatasetProfileApi
from whylabs_client.api.dataset_metadata_api import DatasetMetadataApi
from whylabs_client.api.debug_events_api import DebugEventsApi
from whylabs_client.api.diagnostics_api import DiagnosticsApi
from whylabs_client.api.feature_weights_api import FeatureWeightsApi
from whylabs_client.api.log_api import LogApi
from whylabs_client.api.membership_api import MembershipApi
from whylabs_client.api.models_api import ModelsApi
from whylabs_client.api.monitor_api import MonitorApi
from whylabs_client.api.monitor_diagnostics_api import MonitorDiagnosticsApi
from whylabs_client.api.notification_settings_api import NotificationSettingsApi
from whylabs_client.api.policy_api import PolicyApi
from whylabs_client.api.schema_api import SchemaApi
from whylabs_client.api.security_api import SecurityApi
from whylabs_client.api.sessions_api import SessionsApi
from whylabs_client.api.traces_api import TracesApi
from whylabs_client.api.transactions_api import TransactionsApi
